/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file colourpick.h
 *
 * @type helper
 *
 * @description
 *
 * The colourpicker helper is used to display the RISC OS standard colour picker.
 */

#ifndef __rov_colourpick
#define __rov_colourpick


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * The colour model structure
 * @see colourpick_create()
 * @see colourpick_update()
 * @see Colour picker models
 */
typedef struct colourmodel {
 unsigned char z, r, g, b;
 int ext_size;
 int model;
 int v[4];
} colourmodel;

/**
 * The colourpicker block returned by the ColourPicker module.
 * @see colourpick_create()
 * @see colourpick_close()
 * @see colourpick_update()
 */
typedef void * colourpick_block;

/**
 * Open a colourpicker
 * @param flags the flags for creating the colourpicker window.
 * @param title the title of the colourpicker window.
 * @param x the left hand (screen) coordinate to open it up.
 * @param y the bottom (screen) coordinate to open it up.
 * @param mod the colour model to use.
 * @return the colourpicker block.
 * @see Colour picker creation flags
 */
colourpick_block * colourpick_create(int flags,
				     char * title,
				     int x,
				     int y,
				     colourmodel * mod);

/**
 * Close the colourpicker
 * @param b the colourpicker block returned from colourpick_create()
 */
void colourpick_close(colourpick_block * b);

/**
 * Update the colourpicker
 * @param flags the flags for updating the colourpicker window.
 * @param title the title of the colourpicker window.
 * @param x the left hand (screen) coordinate to open it up.
 * @param y the bottom (screen) coordinate to open it up.
 * @param mod the colourpicker model to use
 * @param b the colourpicker block to use.
 * @see Colour picker update flags.
 */
void colourpick_update(int flags,
		       char * title,
		       int x,
		       int y,
		       colourmodel * mod,
		       colourpick_block * b);

/**
 * @section Colour picker creation flags
 */
#define COLOURPICK_NORMAL	(0<<0)
#define COLOURPICK_MENU		(1<<0)
#define COLOURPICK_TOOLBOX	(2<<0)
#define COLOURPICK_SUBMENU	(3<<0)
#define COLOURPICK_HASNONE	(1<<8)
#define COLOURPICK_ISNONE	(1<<9)
#define COLOURPICK_NOCHANGE	(0<<10)
#define COLOURPICK_ANYCHANGE	(1<<10)
#define COLOURPICK_DRAGCHANGE	(2<<10)
#define COLOURPICK_IGNOREHELP	(1<<12)
#define COLOURPICK_NOKEYS	(1<<13)

/**
 * @section Colour picker update flags
 */
#define COLOURPICK_UPDATEHASNONE	(1<<16)
#define COLOURPICK_UPDATEISNONE		(1<<17)
#define COLOURPICK_UPDATEBUTTONTYPE	(1<<18)
#define COLOURPICK_UPDATEVISIBLEAREA	(1<<19)
#define COLOURPICK_UPDATETITLE		(1<<21)
#define COLOURPICK_UPDATECOLOUR		(1<<22)
#define COLOURPICK_UPDATEMODEL		(1<<23)
#define COLOURPICK_UPDATEIGNOREHELP	(1<<24)
#define COLOURPICK_UPDATENOKEYS		(1<<25)

/**
 * @section Colour picker models
 * These are the models that are defined in the colour picker.
 */
#define COLOURPICK_RGB		(0)
#define COLOURPICK_CMYK		(1)
#define COLOURPICK_HSV		(2)


#ifdef __cplusplus
}
#endif

#endif
